package PureMessage::CachedMultifile;
use strict;
use warnings;
use PureMessage::Multifile::Constants qw($MULTIFILE_DIR);
use ActiveState::Handy qw(cat);
use PureMessage::UTF8::Config qw(%utf8_config);
use ActiveState::UTF8 qw(decode_utf8);
use ActiveState::I18N::UTF8 qw(convert_from_utf8);

sub new {
    my ($proto, $multifile_id, $charset) = @_;

    die(q{Missing required parameter 'multilist_id'}) unless $multifile_id;
    die(q{Missing required parameter 'charset'}) unless $charset;

    my $multifile_dir = qq{$MULTIFILE_DIR/$multifile_id};

    die(qq{$multifile_dir does not exist!}) unless -d $multifile_dir;

    my $class = ref($proto) || $proto;
    my $self = {
        _multifile_id => $multifile_id,
        _multifile_dir => $multifile_dir,
        _charset => $charset,
    };
    bless($self, $class);

    return $self;
}

sub group_multifile_exists {
    my ($self, $group_name) = @_;
    die(q{Missing required parameter 'group_name'}) unless $group_name;
    return (-e qq{$self->{_multifile_dir}/$group_name}) ? 1 : 0;
}

sub get_multifile_id {
    my ($self) = @_;
    return $self->{_multifile_id};
}

sub get_charset {
    my ($self) = @_;
    return $self->{_charset};
}

sub get_content {
    my ($self, $group_name) = @_;
    die(q{Missing required parameter 'group_name'}) unless $group_name;
    die(q{No '} . $self->get_multifile_id()
            . qq{' multifile defined for '$group_name'})
        unless $self->group_multifile_exists($group_name);
    my $group_multifile = qq{$self->{_multifile_dir}/$group_name};
    my $content = cat($group_multifile);
    return $content || '';
}

sub get_encoded_content {
    my ($self, $group_name) = @_;
        
    my $encoded;
    my $content = $self->get_content($group_name);    
    
    my $charset = $self->{_charset};     
    if ($charset eq 'latin1' || $charset =~ /iso[-_]?8859[-_]1/i) {
        $encoded = decode_utf8($content);
    }
    else {
        # Try to use the iconv conversion
        $encoded = convert_from_utf8($content, $charset, \%utf8_config);
        $encoded = $content unless defined $encoded;        
    }
    return $encoded;
}

1;
