package PureMessage::Group::CDBMap;

use strict;
use warnings;

use PureMessage::Version qw($PREFIX);

use Carp qw(croak);
use CDB_File;

sub Tie {
    my ($class) = @_;
    my $self = {};

    $self->{file} = "$PREFIX/etc/members-per-group.cdb";
    $self->{handle} = CDB_File->TIEHASH($self->{file});
    croak "Cannot create CDB handle for file: $self->{file}"
        unless $self->{handle};

    return bless $self, $class;
}

sub refresh {
    my ($self) = @_;
    my $mtime = (stat $self->{file})[9];
    return 0 if $self->{mtime} and $mtime == $self->{mtime};

    $self->{handle} = CDB_File->TIEHASH($self->{file});
    $self->{mtime} = (stat $self->{file})[9];
    return 1;
}

sub lookup {
    my ($self, $addr) = @_;

    return undef unless $addr;

    # XXX The passed in $addr must be in address format, namely
    # <user>@<domain>. It cannot handle RFC822 address headers.

    my ($user, $domain) = $addr =~ /^(.+)\@(.+)$/;
    return undef unless ($user && $domain);
    ($user, $domain) = (lc $user, lc $domain);

    my $group = undef;

    # XXX The logic here is taking the pre-defined order for group mapping,
    # that is, exact address, user part, and then domain part.
    return $group if($group = $self->{handle}->FETCH($addr));
    return $group if($group = $self->{handle}->FETCH("$user\@"));
    return $group if($group = $self->{handle}->FETCH("\@$domain"));

    # XXX Search all domains for sub-domains and stop at '*.*'
    my @domain_parts = split(qr/\./,$domain);
    while(scalar(@domain_parts) > 1 && shift @domain_parts) {
        $domain =  join '.', @domain_parts; 
        return $group if($group = $self->{handle}->FETCH("\@$domain"));
    }

    return $group;
}

1;
