package PureMessage::Group::Policy;
use strict;
use warnings;
use base 'Exporter';
use PureMessage::Resources::Manager;
use PureMessage::Group::PermissionItem;
use PureMessage::Group::PolicyOption;

our @EXPORT_OK = qw/add_checkbox_option delete_checkbox_option/;

sub add_checkbox_option {
    my %opts = @_;

    # Force all policy IDs to lowercase
    $opts{list} = lc($opts{list});

    # Define the new resource
    my $store = PureMessage::Resources::Store::DB->new;
    my $mgr = PureMessage::Resources::Manager->new(store => $store);
    $mgr->Define( 
        store => 'db',
        name => $opts{list},
        type => 'list',
        attributes => {
            description => $opts{description},
            match_type => 'is',
            name => $opts{name},
        },
    ); 
    # create a new instance of this resource
    $mgr->add($opts{list});

    PureMessage::Group::PermissionItem::ReadWrite->add_permission_item(
        qq{configuration.policysettings.$opts{list}}
    );

    my %policy_opts = (
        name => $opts{list},
        description => $opts{description},
        default_on => ($opts{default} eq 'on' ? 'true' : 'false'),
        opt_in => ($opts{style} eq 'optin' ? 'true' : 'false'),
        list_name => $opts{list},
    );
    my $opt = PureMessage::Group::PolicyOption::OptIn->create(\%policy_opts);
}

sub delete_checkbox_option {
    my %opts = @_;

    # TODO - Delete list from resources and local?

    eval {
        PureMessage::Group::PermissionItem::ReadWrite->delete_permission_item(
            qq{configuration.policysettings.$opts{list}}
        );

        my $opt = PureMessage::Group::PolicyOption::OptIn->search(
                        name => $opts{list})->first;
        if ($opt) {
            $opt->delete;
        }
    };
    if ($@) {
        die "There was an error deleting policy option '$opts{list}': $@";
    }
}

1;
