package PureMessage::GroupAdmin;
use strict;
use warnings;
use base 'PureMessage::DBI';
use PureMessage::Group;
use PureMessage::User;

__PACKAGE__->table(q{group_admin});
__PACKAGE__->columns(Primary => q{group_admin_id});
__PACKAGE__->columns(All => qw/group_admin_id group_name user_name/);
__PACKAGE__->has_a(user_name => 'PureMessage::User');
__PACKAGE__->has_a(group_name => 'PureMessage::Group');
if (__PACKAGE__->can(q{pg_version})) {
    __PACKAGE__->sequence(q{group_admin_group_admin_id_seq});
}

# friendly wrapper to create a new user
sub add_group_admin {
    my ($group_name, $user_name) = @_;
    die qq{Must supply a group!\n} unless defined($group_name);
    die qq{Must supply a user!\n} unless defined($user_name);
    $user_name = lc($user_name);
    $group_name = lc($group_name);
    my $user = PureMessage::User->search(user_name => $user_name)->first;
    die "The '$user_name' user does not exist.  Please create it first.\n" unless $user;
    my $group = PureMessage::Group->search(group_name => $group_name)->first;
    die "The '$group_name' group does not exist.  Please create it first.\n" unless $group;
    my $group_admin;
    eval {
        my %args = (group_name => $group_name, user_name => $user_name);
        $group_admin = __PACKAGE__->search(\%args)->first;
        die "$user_name is already associated with $group_name.\n" if $group_admin;
        $group_admin = __PACKAGE__->create(\%args);
    };
    if ($@) {
        die qq{Error creating group admin record: $@\n};
    }
    return $group_admin;
}

sub delete_group_admin {
    my ($group_name, $user_name) = @_;
    die qq{Must supply a group!\n} unless defined($group_name);
    die qq{Must supply a user!\n} unless defined($user_name);
    $user_name = lc($user_name);
    $group_name = lc($group_name);
    my $user = PureMessage::User->search(user_name => $user_name)->first;
    die "The '$user_name' user does not exist.  Please create it first.\n" unless $user;
    my $group = PureMessage::Group->search(group_name => $group_name)->first;
    die "The '$group_name' group does not exist.  Please create it first.\n" unless $group;
    my $group_admin;
    eval {
        $group_admin = __PACKAGE__->search({ group_name => $group_name,
                                             user_name => $user_name
                                           })->first;
        unless ($group_admin) {
            die "Group '$group_name' is not associated with user '$user_name'.\n";
        }
        $group_admin->delete();
    };
    if ($@) {
        die qq{Error deleting group admin record: $@\n};
    }
}

1;
