package PureMessage::MultifileCache;
use strict;
use warnings;
use PureMessage::Multifile::Constants qw($MULTIFILE_CONF);
use PureMessage::CachedMultifile;
use ActiveState::Config::Simple qw(config_parse_file);

sub new {
    my ($proto) = @_;
    my $class = ref($proto) || $proto;
    my $self = {
        _multifiles => {},
        _timestamp => 0,
    };
    bless($self, $class);

    $self->_refresh();

    return $self;
}

sub _refresh {
    my ($self) = @_;

    unless (-e $MULTIFILE_CONF) {
        $self->{_multifiles} = {};
        $self->{_timestamp} = 0;
        return;
    }

    my $timestamp = (stat($MULTIFILE_CONF))[9];
    return unless ($timestamp > $self->{_timestamp});

    # This is a bit harsh, but it will do for now
    $self->{_multifiles} = {};

    my $config = config_parse_file($MULTIFILE_CONF);
    for my $multifile_id (keys(%{$config->{multifile}})) {
        my $multifile = PureMessage::CachedMultifile->new(
            $multifile_id,
            $config->{multifile}{$multifile_id}{charset}
            );
        $self->{_multifiles}{$multifile_id} = $multifile;
    }

    $self->{_timestamp} = $timestamp;
}

sub get_multifile {
    my ($self, $multifile_id) = @_;
    die(q{Missing required parameter 'multifile_id'}) unless $multifile_id;
    $self->_refresh();
    die(qq{Multifile '$multifile_id' does not exist!})
        unless exists($self->{_multifiles}{$multifile_id});
    return $self->{_multifiles}{$multifile_id};
}

1;
